@@ -170,11 +170,26 @@ wp_spa_json_new (const gchar *data, size_t size)
  */
 WpSpaJson *
 wp_spa_json_new_from_string (const gchar *json_str)
+{
+  return wp_spa_json_new_from_stringn(json_str, strlen (json_str));
+}
+
+/*!
+ * \brief Constructs a new WpSpaJson from a JSON string with specific length.
+ *
+ * \ingroup wpspajson
+ * \param json_str a JSON string
+ * \param len the specific length of the string
+ * \returns a new WpSpaJson that references the data in \a json_str. \a json_str
+ *   is not copied, so it needs to stay alive.
+ */
+WpSpaJson *
+wp_spa_json_new_from_stringn (const gchar *json_str, size_t len)
 {
   WpSpaJson *self = g_slice_new0 (WpSpaJson);
   g_ref_count_init (&self->ref);
   self->flags = FLAG_NO_OWNERSHIP;
-  spa_json_init (&self->json_data, json_str, strlen (json_str));
+  spa_json_init (&self->json_data, json_str, len);
   self->builder = NULL;
   self->data = (gchar *)self->json_data.cur;
   self->size = self->json_data.end - self->json_data.cur;
@@ -808,7 +823,6 @@ wp_spa_json_object_get_valist (WpSpaJson *self, va_list args)
     g_autofree gchar *key_str = NULL;
     WpSpaJson *value = NULL;
 
-    g_return_val_if_fail (wp_spa_json_is_string (key), FALSE);
     key_str = wp_spa_json_parse_string (key);
     g_return_val_if_fail (key_str, FALSE);
 
